Keyfile

Struct Keyfile 

pub struct Keyfile {
    pub path: String,
    /* private fields */
}

Fields

path: String

Implementations

Source

impl Keyfile

pub fn new( path: String, name: Option<String>, should_save_to_env: bool, ) -> Result<Self, KeyFileError>

Creates a new Keyfile instance.

Arguments:
    path (String): The file system path where the keyfile is stored.
    name (Option<String>): Optional name for the keyfile. Defaults to "Keyfile" if not provided.
    should_save_to_env (bool): If ``True``, saves the password to environment variables.
Returns:
    keyfile (Keyfile): A new Keyfile instance.
pub fn get_keypair( &self, password: Option<String>, ) -> Result<Keypair, KeyFileError>

Returns the keypair from path, decrypts data if the file is encrypted.

Arguments:
    password (Option<String>): The password used to decrypt the data. If ``None``, asks for user input.
Returns:
    keypair (Keypair): The Keypair loaded from the file.
pub fn get_name(&self) -> Result<String, KeyFileError>

Loads the name from keyfile.name or raises an error.

pub fn get_path(&self) -> Result<String, KeyFileError>

Loads the name from keyfile.path or raises an error.

pub fn data(&self) -> Result<Vec<u8>, KeyFileError>

Returns the keyfile data under path.

pub fn keyfile_data(&self) -> Result<Vec<u8>, KeyFileError>

Returns the keyfile data under path.

pub fn env_var_name(&self) -> Result<String, KeyFileError>

Returns local environment variable key name based on Keyfile path.

pub fn set_keypair( &self, keypair: Keypair, encrypt: bool, overwrite: bool, password: Option<String>, ) -> Result<(), KeyFileError>

Writes the keypair to the file and optionally encrypts data.

Arguments:
    keypair (Keypair): The keypair object to be stored.
    encrypt (bool): If ``True``, encrypts the keyfile data.
    overwrite (bool): If ``True``, overwrites existing file without prompting.
    password (Option<String>): The password used to encrypt the data. If ``None``, asks for user input.
pub fn make_dirs(&self) -> Result<(), KeyFileError>

Creates directories for the path if they do not exist.

pub fn exists_on_device(&self) -> Result<bool, KeyFileError>

Returns True if the file exists on the device.

Returns:
    readable (bool): ``True`` if the file is readable.
pub fn is_readable(&self) -> Result<bool, KeyFileError>

Returns True if the file under path is readable.

pub fn is_writable(&self) -> Result<bool, KeyFileError>

Returns True if the file under path is writable.

Returns:
    writable (bool): ``True`` if the file is writable.
pub fn is_encrypted(&self) -> Result<bool, KeyFileError>

Returns True if the file under path is encrypted.

Returns:
    encrypted (bool): ``True`` if the file is encrypted.
pub fn _may_overwrite(&self) -> bool

Asks the user if it is okay to overwrite the file.

pub fn check_and_update_encryption( &self, print_result: bool, no_prompt: bool, ) -> Result<bool, KeyFileError>

Check the version of keyfile and update if needed.

Arguments:
    print_result (bool): If ``True``, prints the result of the encryption check.
    no_prompt (bool): If ``True``, skips user prompts during the update process.
Returns:
    updated (bool): ``True`` if the keyfile was successfully updated to the latest encryption method.
pub fn encrypt(&self, password: Option<String>) -> Result<(), KeyFileError>

Encrypts the file under the path.

Arguments:
    password (Option<String>): The password used to encrypt the data. If ``None``, asks for user input.
pub fn decrypt(&self, password: Option<String>) -> Result<(), KeyFileError>

Decrypts the file under the path.

Arguments:
    password (Option<String>): The password used to decrypt the data. If ``None``, asks for user input.
pub fn _read_keyfile_data_from_file(&self) -> Result<Vec<u8>, KeyFileError>

Reads the keyfile data from the file.

Returns:
    keyfile_data (Vec<u8>): The keyfile data stored under the path.
Raises:
    KeyFileError: Raised if the file does not exist or is not readable.
pub fn _write_keyfile_data_to_file( &self, keyfile_data: &[u8], overwrite: bool, ) -> Result<(), KeyFileError>

Writes the keyfile data to the file.

Arguments:
    keyfile_data: The byte data to store under the path.
    overwrite: If true, overwrites the data without asking for permission from the user. Default is false.
pub fn save_password_to_env( &self, password: Option<String>, ) -> Result<String, KeyFileError>

Saves the key’s password to the associated local environment variable.

Arguments:
    password (Option<String>): The password to save. If ``None``, asks for user input.
Returns:
    encrypted_password_base64 (str): The base64-encoded encrypted password.
pub fn remove_password_from_env(&self) -> Result<bool, KeyFileError>

Removes the password associated with the Keyfile from the local environment.