Functions
- are_
bytes_ valid_ ed25519_ pubkey - Checks if the given public_key is a valid ed25519 key.
- get_
ss58_ format - Returns the SS58 format of the given address string.
- is_
string_ valid_ ed25519_ pubkey - Checks if the given public_key is a valid ed25519 key.
- is_
valid_ bittensor_ address_ or_ public_ key - Checks if the given address is a valid destination address.
- is_
valid_ ss58_ address - Checks if the given address is a valid ss58 address.
- When running inside a Python process, output must go through Python’s
sys.stdoutto stay synchronized with Python-level I/O (e.g. Jupyter, logging redirects). In pure Rust mode, standard stdout is used directly. - prompt
- Prompts the user and returns the response, if any.
- prompt_
password - Prompts the user with a password entry and returns the response, if any.